@@ -8,6 +8,7 @@
 #'
 #' @return The aspect ratio
 #' @export
+#' @keywords internal
 #' @examples
 #'
 #' library(terra)
@@ -34,13 +35,8 @@ asp_ratio <- function(x) {
 
 rpic_crop <- function(crop, box_marg, new_rast) {
   if (crop) {
-    crop_extent <- terra::ext(
-      box_marg[c(1, 3, 2, 4)]
-    )
-    new_rast <- terra::crop(
-      new_rast,
-      crop_extent
-    )
+    crop_extent <- terra::ext(box_marg[c(1, 3, 2, 4)])
+    new_rast <- terra::crop(new_rast, crop_extent)
   }
 
   return(new_rast)
@@ -68,21 +64,19 @@ rpic_read <- function(img, crs = NA) {
 
     # On error
     if (err_dwnload) {
-      stop("Cannot reach img on url ",
-        img,
-        call. = FALSE
-      )
+      stop("Cannot reach img on url ", img, call. = FALSE)
     }
     # nocov end
+
     # If everything is well, rename img
     img <- tmp
   }
 
   if (!file.exists(img)) stop("'img' file not found", call. = FALSE)
-
   # pngs
-  if (tools::file_ext(img) %in% c("png")) {
+  if ("png" %in% tools::file_ext(img)) {
     pngfile <- png::readPNG(img) * 255
+
     # Give transparency if available
     if (dim(pngfile)[3] == 4) {
       nrow <- dim(pngfile)[1]
@@ -104,20 +98,16 @@ rpic_read <- function(img, crs = NA) {
     # jpg/jpeg and tif/tiff
 
     rast <- suppressWarnings(terra::rast(img))
-
     terra::crs(rast) <- crs
     return(rast)
   } else {
-    stop("'img' only accepts 'png', 'jpg' or 'jpeg' files",
-      call. = FALSE
-    )
+    stop("'img' only accepts 'png', 'jpg' or 'jpeg' files", call. = FALSE)
   }
 }
 
 
 rpic_input <- function(x, crs) {
   # Convert sf to SpatVector
-
   if (inherits(x, "sf") || inherits(x, "sfc")) {
     x <- terra::vect(x)
   }
@@ -131,60 +121,28 @@ rpic_input <- function(x, crs) {
     }
 
     crs <- terra::crs(x)
-
-    box <- c(
-      terra::xmin(x),
-      terra::ymin(x),
-      terra::xmax(x),
-      terra::ymax(x)
-    )
+    box <- c(terra::xmin(x), terra::ymin(x), terra::xmax(x), terra::ymax(x))
   } else if (inherits(x, "sfg")) {
     x <- terra::vect(x)
-    box <- c(
-      terra::xmin(x),
-      terra::ymin(x),
-      terra::xmax(x),
-      terra::ymax(x)
-    )
+    box <- c(terra::xmin(x), terra::ymin(x), terra::xmax(x), terra::ymax(x))
   } else if (inherits(x, "SpatExtent")) {
-    box <- c(
-      terra::xmin(x),
-      terra::ymin(x),
-      terra::xmax(x),
-      terra::ymax(x)
-    )
+    box <- c(terra::xmin(x), terra::ymin(x), terra::xmax(x), terra::ymax(x))
   } else if (inherits(x, "bbox") && length(x) == 4) {
-    box <- c(
-      x["xmin"],
-      x["ymin"],
-      x["xmax"],
-      x["ymax"]
-    )
+    box <- c(x["xmin"], x["ymin"], x["xmax"], x["ymax"])
     box <- unname(box)
   } else if (is.numeric(x) && length(x) == 4) {
-    box <- c(
-      x[1],
-      x[2],
-      x[3],
-      x[4]
-    )
+    box <- c(x[1], x[2], x[3], x[4])
   } else {
     stop("Don't know how to extract a bounding box from 'x'")
   }
 
-
-
   if (missing(crs)) {
     message("'crs' is NA.")
     crs <- NA
   }
 
   # Output object is a list
-  result <- list(
-    x = x,
-    box = box,
-    crs = crs
-  )
+  result <- list(x = x, box = box, crs = crs)
 
   return(result)
 }
